WikhaPlayerStrings class

Constructors

WikhaPlayerStrings({String play = 'Lecture', String pause = 'Pause', String settings = 'Paramètres (Audio & Sous-titres)', String audio = 'Audio', String subtitles = 'Sous-titres', String off = 'Désactivé', String normalSpeed = 'Normale', String quality = 'Qualité', String playlist = 'Playlist', String pip = 'Image dans l\'image', String cast = 'Caster / AirPlay', String fullscreen = 'Plein écran'})
const
WikhaPlayerStrings.en()
factory
WikhaPlayerStrings.fr()
factory

Properties

audio String
final
cast String
final
fullscreen String
final
hashCode int
The hash code for this object.
no setterinherited
normalSpeed String
final
off String
final
pause String
final
pip String
final
play String
final
playlist String
final
quality String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings String
final
subtitles String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited